public inbox for passt-dev@passt.top
 help / color / mirror / code / Atom feed
* [PATCH] migrate: Rename v1 address functions to v2 for clarity
@ 2026-03-03 19:04 Jon Maloy
  2026-03-05  0:38 ` Stefano Brivio
  0 siblings, 1 reply; 3+ messages in thread
From: Jon Maloy @ 2026-03-03 19:04 UTC (permalink / raw)
  To: sbrivio, dgibson, david, jmaloy, passt-dev

Some migration address structures and functions have a _v1 suffix.
This is confusing, since they are currently handling version 2 of
the migration protocol. We are soon going to introduce a new version
3 of the protocol, so we choose to give these functions the correct
suffix _v2 instead. This is in correspondence with current reality,
and will help make a clearer distinction between the old and the new
versions of those functions.

Signed-off-by: Jon Maloy <jmaloy@redhat.com>
Reviewed-by: David Gibson <david@gibson.dropbear.id.au>
---
 migrate.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/migrate.c b/migrate.c
index 13bacab..1e8858a 100644
--- a/migrate.c
+++ b/migrate.c
@@ -29,13 +29,13 @@
 #define MIGRATE_MAGIC		0xB1BB1D1B0BB1D1B0
 
 /**
  * struct migrate_seen_addrs_v1 - Migratable guest addresses for v1 state stream
  * @addr6:	Observed guest IPv6 address
  * @addr6_ll:	Observed guest IPv6 link-local address
  * @addr4:	Observed guest IPv4 address
  * @mac:	Observed guest MAC address
  */
-struct migrate_seen_addrs_v1 {
+struct migrate_seen_addrs_v2 {
 	struct in6_addr addr6;
 	struct in6_addr addr6_ll;
 	struct in_addr addr4;
@@ -43,7 +43,7 @@ struct migrate_seen_addrs_v1 {
 } __attribute__((packed));
 
 /**
  * seen_addrs_source_v1() - Copy and send guest observed addresses from source
  * @c:		Execution context
  * @stage:	Migration stage, unused
  * @fd:		File descriptor for state transfer
@@ -51,10 +51,10 @@ struct migrate_seen_addrs_v1 {
  * Return: 0 on success, positive error code on failure
  */
 /* cppcheck-suppress [constParameterCallback, unmatchedSuppression] */
-static int seen_addrs_source_v1(struct ctx *c,
+static int seen_addrs_source_v2(struct ctx *c,
 				const struct migrate_stage *stage, int fd)
 {
-	struct migrate_seen_addrs_v1 addrs = {
+	struct migrate_seen_addrs_v2 addrs = {
 		.addr6 = c->ip6.addr_seen,
 		.addr6_ll = c->ip6.addr_ll_seen,
 		.addr4 = c->ip4.addr_seen,
@@ -71,17 +71,17 @@ static int seen_addrs_source_v1(struct ctx *c,
 }
 
 /**
  * seen_addrs_target_v1() - Receive and use guest observed addresses on target
  * @c:		Execution context
  * @stage:	Migration stage, unused
  * @fd:		File descriptor for state transfer
  *
  * Return: 0 on success, positive error code on failure
  */
-static int seen_addrs_target_v1(struct ctx *c,
+static int seen_addrs_target_v2(struct ctx *c,
 				const struct migrate_stage *stage, int fd)
 {
-	struct migrate_seen_addrs_v1 addrs;
+	struct migrate_seen_addrs_v2 addrs;
 
 	(void)stage;
 
@@ -100,8 +100,8 @@ static int seen_addrs_target_v1(struct ctx *c,
 static const struct migrate_stage stages_v2[] = {
 	{
 		.name = "observed addresses",
-		.source = seen_addrs_source_v1,
-		.target = seen_addrs_target_v1,
+		.source = seen_addrs_source_v2,
+		.target = seen_addrs_target_v2,
 	},
 	{
 		.name = "prepare flows",
@@ -29,13 +29,13 @@
 
 /**
- * struct migrate_seen_addrs_v1 - Migratable guest addresses for v1 state stream
+ * struct migrate_seen_addrs_v2 - Migratable guest addresses for v2 state stream
  * @addr6:	Observed guest IPv6 address
  * @addr6_ll:	Observed guest IPv6 link-local address
@@ -43,7 +43,7 @@ struct migrate_seen_addrs_v1 {
 
 /**
- * seen_addrs_source_v1() - Copy and send guest observed addresses from source
+ * seen_addrs_source_v2() - Copy and send guest observed addresses from source
  * @c:		Execution context
  * @stage:	Migration stage, unused
@@ -71,17 +71,17 @@ static int seen_addrs_source_v1(struct ctx *c,
 
 /**
- * seen_addrs_target_v1() - Receive and use guest observed addresses on target
+ * seen_addrs_target_v2() - Receive and use guest observed addresses on target
  * @c:		Execution context
  * @stage:	Migration stage, unused
-- 
2.52.0


^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2026-03-05  1:45 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2026-03-03 19:04 [PATCH] migrate: Rename v1 address functions to v2 for clarity Jon Maloy
2026-03-05  0:38 ` Stefano Brivio
2026-03-05  1:27   ` David Gibson

Code repositories for project(s) associated with this public inbox

	https://passt.top/passt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for IMAP folder(s).